@@ -12,15 +12,16 @@
 
 import base64
 import datetime
+import mock
 
 from castellan.common.exception import KeyManagerError
+from castellan.common.exception import ManagedObjectNotFoundError
 import cryptography.exceptions as crypto_exceptions
 from cryptography.hazmat.backends import default_backend
 from cryptography.hazmat.primitives.asymmetric import dsa
 from cryptography.hazmat.primitives.asymmetric import ec
 from cryptography.hazmat.primitives.asymmetric import padding
 from cryptography.hazmat.primitives.asymmetric import rsa
-import mock
 from oslo_utils import timeutils
 
 from cursive import exception
@@ -53,13 +54,17 @@ class FakeKeyManager(object):
         self.certs = {'invalid_format_cert':
                       FakeCastellanCertificate('A' * 256, 'BLAH'),
                       'valid_format_cert':
-                      FakeCastellanCertificate('A' * 256, 'X.509')}
+                      FakeCastellanCertificate('A' * 256, 'X.509'),
+                      'invalid-cert-uuid': ManagedObjectNotFoundError()
+                      }
 
     def get(self, context, cert_uuid):
         cert = self.certs.get(cert_uuid)
 
         if cert is None:
             raise KeyManagerError("No matching certificate found.")
+        if isinstance(cert, ManagedObjectNotFoundError):
+            raise cert
 
         return cert
 
@@ -101,15 +106,15 @@ class FakeCryptoCertificate(object):
         return self.cert_not_valid_after
 
 
-class BadPublicKey(object):
-
-    def verifier(self, signature, padding, hash_method):
-        return None
-
-
 class TestSignatureUtils(base.TestCase):
     """Test methods of signature_utils"""
 
+    def setUp(self):
+        super(TestSignatureUtils, self).setUp()
+
+    def tearDown(self):
+        super(TestSignatureUtils, self).tearDown()
+
     def test_should_create_verifier(self):
         image_props = {CERT_UUID: 'CERT_UUID',
                        HASH_METHOD: 'HASH_METHOD',
@@ -237,7 +242,7 @@ class TestSignatureUtils(base.TestCase):
 
     @mock.patch('cursive.signature_utils.get_public_key')
     def test_get_verifier_none(self, mock_get_pub_key):
-        mock_get_pub_key.return_value = BadPublicKey()
+        mock_get_pub_key.return_value = None
         img_sig_cert_uuid = 'fea14bc2-d75f-4ba5-bccc-b5c924ad0693'
         self.assertRaisesRegex(exception.SignatureVerificationError,
                                'Error occurred while creating'
@@ -283,7 +288,8 @@ class TestSignatureUtils(base.TestCase):
                                'RSB-PSS')
 
     @mock.patch('cursive.signature_utils.get_certificate')
-    def test_get_public_key_rsa(self, mock_get_cert):
+    @mock.patch('cursive.certificate_utils.verify_certificate')
+    def test_get_public_key_rsa(self, mock_verify_cert, mock_get_cert):
         fake_cert = FakeCryptoCertificate()
         mock_get_cert.return_value = fake_cert
         sig_key_type = signature_utils.SignatureKeyType.lookup(
@@ -294,7 +300,8 @@ class TestSignatureUtils(base.TestCase):
         self.assertEqual(fake_cert.public_key(), result_pub_key)
 
     @mock.patch('cursive.signature_utils.get_certificate')
-    def test_get_public_key_ecc(self, mock_get_cert):
+    @mock.patch('cursive.certificate_utils.verify_certificate')
+    def test_get_public_key_ecc(self, mock_verify_cert, mock_get_cert):
         fake_cert = FakeCryptoCertificate(TEST_ECC_PRIVATE_KEY.public_key())
         mock_get_cert.return_value = fake_cert
         sig_key_type = signature_utils.SignatureKeyType.lookup('ECC_SECP521R1')
@@ -303,7 +310,8 @@ class TestSignatureUtils(base.TestCase):
         self.assertEqual(fake_cert.public_key(), result_pub_key)
 
     @mock.patch('cursive.signature_utils.get_certificate')
-    def test_get_public_key_dsa(self, mock_get_cert):
+    @mock.patch('cursive.certificate_utils.verify_certificate')
+    def test_get_public_key_dsa(self, mock_verify_cert, mock_get_cert):
         fake_cert = FakeCryptoCertificate(TEST_DSA_PRIVATE_KEY.public_key())
         mock_get_cert.return_value = fake_cert
         sig_key_type = signature_utils.SignatureKeyType.lookup(
@@ -314,7 +322,9 @@ class TestSignatureUtils(base.TestCase):
         self.assertEqual(fake_cert.public_key(), result_pub_key)
 
     @mock.patch('cursive.signature_utils.get_certificate')
-    def test_get_public_key_invalid_key(self, mock_get_certificate):
+    @mock.patch('cursive.certificate_utils.verify_certificate')
+    def test_get_public_key_invalid_key(self, mock_verify_certificate,
+                                        mock_get_certificate):
         bad_pub_key = 'A' * 256
         mock_get_certificate.return_value = FakeCryptoCertificate(bad_pub_key)
         sig_key_type = signature_utils.SignatureKeyType.lookup(
@@ -335,34 +345,6 @@ class TestSignatureUtils(base.TestCase):
         self.assertEqual(x509_cert,
                          signature_utils.get_certificate(None, cert_uuid))
 
-    @mock.patch('cryptography.x509.load_der_x509_certificate')
-    @mock.patch('castellan.key_manager.API', return_value=FakeKeyManager())
-    def test_get_expired_certificate(self, mock_key_manager_API,
-                                     mock_load_cert):
-        cert_uuid = 'valid_format_cert'
-        x509_cert = FakeCryptoCertificate(
-            not_valid_after=timeutils.utcnow() -
-            datetime.timedelta(hours=1))
-        mock_load_cert.return_value = x509_cert
-        self.assertRaisesRegex(exception.SignatureVerificationError,
-                               'Certificate is not valid after: .*',
-                               signature_utils.get_certificate, None,
-                               cert_uuid)
-
-    @mock.patch('cryptography.x509.load_der_x509_certificate')
-    @mock.patch('castellan.key_manager.API', return_value=FakeKeyManager())
-    def test_get_not_yet_valid_certificate(self, mock_key_manager_API,
-                                           mock_load_cert):
-        cert_uuid = 'valid_format_cert'
-        x509_cert = FakeCryptoCertificate(
-            not_valid_before=timeutils.utcnow() +
-            datetime.timedelta(hours=1))
-        mock_load_cert.return_value = x509_cert
-        self.assertRaisesRegex(exception.SignatureVerificationError,
-                               'Certificate is not valid before: .*',
-                               signature_utils.get_certificate, None,
-                               cert_uuid)
-
     @mock.patch('castellan.key_manager.API', return_value=FakeKeyManager())
     def test_get_certificate_key_manager_fail(self, mock_key_manager_API):
         bad_cert_uuid = 'fea14bc2-d75f-4ba5-bccc-b5c924ad0695'
@@ -378,3 +360,11 @@ class TestSignatureUtils(base.TestCase):
                                'Invalid certificate format: .*',
                                signature_utils.get_certificate, None,
                                cert_uuid)
+
+    @mock.patch('castellan.key_manager.API', return_value=FakeKeyManager())
+    def test_get_certificate_id_not_exist(self, mock_key_manager):
+        bad_cert_uuid = 'invalid-cert-uuid'
+        self.assertRaisesRegex(exception.SignatureVerificationError,
+                               'Certificate not found with ID: .*',
+                               signature_utils.get_certificate, None,
+                               bad_cert_uuid)
